@@ -30,9 +30,12 @@ from monitoring.alarmdefs import constants
 from monitoring.alarmdefs import forms as alarm_forms
 from monitoring.alarmdefs import tables as alarm_tables
 from monitoring import api
-from django.core.paginator import Paginator, EmptyPage, PageNotAnInteger
+from django.core.paginator import Paginator, EmptyPage
 
 LIMIT = 10
+PREV_PAGE_LIMIT = 100
+
+
 class IndexView(tables.DataTableView):
     table_class = alarm_tables.AlarmsTable
     template_name = constants.TEMPLATE_PREFIX + 'alarm.html'
@@ -56,12 +59,20 @@ class IndexView(tables.DataTableView):
     def get_context_data(self, **kwargs):
         context = super(IndexView, self).get_context_data(**kwargs)
         contacts = []
+        prev_page_stack = []
         page_offset = self.request.GET.get('page_offset')
 
-        if page_offset == None:
+        if self.request.session.has_key('prev_page_stack'):
+            prev_page_stack = self.request.session['prev_page_stack']
+
+        if page_offset is None:
             page_offset = 0
+            prev_page_stack = []
         try:
-            results = api.monitor.alarmdef_list(self.request, page_offset, LIMIT)
+            # To judge whether there is next page, get LIMIT + 1
+            results = api.monitor.alarmdef_list(self.request, page_offset,
+                                                LIMIT + 1)
+            num_results = len(results)
             paginator = Paginator(results, LIMIT)
             contacts = paginator.page(1)
         except EmptyPage:
@@ -72,11 +83,24 @@ class IndexView(tables.DataTableView):
 
         context["contacts"] = contacts
 
-        if len(context["contacts"]) < LIMIT:
+        if num_results < LIMIT + 1:
             context["page_offset"] = None
         else:
             context["page_offset"] = contacts.object_list[-1]["id"]
 
+        if page_offset in prev_page_stack:
+            index = prev_page_stack.index(page_offset)
+            prev_page_stack = prev_page_stack[0:index]
+
+        prev_page_offset = prev_page_stack[-1] if prev_page_stack else None
+        if prev_page_offset is not None:
+            context["prev_page_offset"] = prev_page_offset
+
+        if len(prev_page_stack) > PREV_PAGE_LIMIT:
+            del prev_page_stack[0]
+        prev_page_stack.append(str(page_offset))
+        self.request.session['prev_page_stack'] = prev_page_stack
+
         return context
 
 
@@ -100,7 +124,7 @@ class AlarmCreateView(forms.ModalFormView):
 
 
 def transform_alarm_data(obj):
-    obj['apply_to'] = '1' if obj['match_by'] else '2'
+    obj['match_by'] = ','.join(obj['match_by'])
     return obj
 
 
