@@ -17,6 +17,8 @@ from django.conf.urls import patterns  # noqa
 from django.conf.urls import url  # noqa
 
 from monitoring.overview import views
+from monitoring.config import local_settings as settings
+
 
 urlpatterns = patterns(
     '',
@@ -24,4 +26,8 @@ urlpatterns = patterns(
     url(r'^status', views.StatusView.as_view(), name='status'),
     url(r'^proxy\/(?P<restpath>.*)$', views.MonascaProxyView.as_view()),
     url(r'^proxy', views.MonascaProxyView.as_view(), name='proxy'),
+    url(r'^logs_proxy(?P<url>.*)$',
+        views.KibanaProxyView.as_view(
+            base_url=settings.KIBANA_HOST), name='kibana_proxy'
+        ),
 )
